#!/bin/ksh
# ident @(#)process_backup.cgi	1.19     99/10/13 SMI
# Copyright 1997 Sun Microsystems, Inc. All Rights Reserved

MODULE=misc/backup-admin
. /opt/netra/SUNWnetra/lib/netra.globals

check_drive()
{
	if [[ -z $WWW_drive ]]; then
		netra_html_error drive_err $no_drive_selected
	fi
}

check_days()
{
	if [[ -n $WWW_sunday ]]; then
		append days 0
		daylist="$daylist<br>$sunday"
	fi
	if [[ -n $WWW_monday ]]; then
		append days 1
		daylist="$daylist<br>$monday"
	fi
	if [[ -n $WWW_tuesday ]]; then
		append days 2
		daylist="$daylist<br>$tuesday"
	fi
	if [[ -n $WWW_wednesday ]]; then
		append days 3
		daylist="$daylist<br>$wednesday"
	fi
	if [[ -n $WWW_thursday ]]; then
		append days 4
		daylist="$daylist<br>$thursday"
	fi
	if [[ -n $WWW_friday ]]; then
		append days 5
		daylist="$daylist<br>$friday"
	fi
	if [[ -n $WWW_saturday ]]; then
		append days 6
		daylist="$daylist<br>$saturday"
	fi

	daylist=${daylist#"<br>"}
	if [[ -z $days ]]; then
		netra_html_error day_err $no_day_selected
	fi
}

show_drive()
{
	printf "<td>$backup_device_label:<td>$device_format<tr>\n" $WWW_drive
}

show_dirs()
{
    # Strip off leading <br>'s first
    dirlist=${dirlist#"<br>"}
    dirlist2=${dirlist2#"<br>"}

	print "<td>$directory_label:<td>$dirlist<td>$dirlist2<tr>"
}

show_time()
{
	((time=WWW_time+WWW_ampm*12))
	netra_strftime -h $time "$time_format"
}

create_script()
{
        cat > $backup_script <<- EOF
#!/bin/ksh

device=/dev/rmt/$WWW_drive
exit_cmd=$extra
mail_root=$mail_root
admin_root=$admin_root
http_roots="$http_roots"
ftp_dir=$ftp_dir
home_dir=/export/home
savecfg_dir=$savecfg_dir
misc_dir="$WWW_misc_dir"
restore_cfg=$restore_cfg
days=$days
time=$time
tar_options=cf
log_file=/tmp/.log.\$\$
admin=root
machine=\`uname -n\`
mail=/usr/bin/mailx
echo "\$machine tape backup report" >\$log_file
for i in \$restore_cfg $backup_list
do
    directories="\$directories .\$i"
    misc_grep=\`echo "\$misc_dir" | grep \$i \`
	  # Here work out what to put in the result mail
    if [ \$i == "\$mail_dir" ]; then
        echo "$mail_dir: \$mail_root" >>\$log_file
    elif [ \$i == "\$admin_root" ]; then
        echo "$html_dir: \$admin_root" >>\$log_file
    elif [ \$i == "\$http_roots" ]; then
        echo "$html_dir: \$http_roots" >>\$log_file
    elif [ \$i == "\$ftp_dir" ]; then
        echo "$aftp_dir: \$ftp_dir" >>\$log_file
    elif [ \$i == "\$home_dir" ]; then
        echo "$user_dir: \$home_dir" >>\$log_file
    elif [ \$i == "\$savecfg_dir" ]; then
        echo "$conf_dir: \$savecfg_dir" >>\$log_file
    elif [[ -n \$misc_grep ]]; then
        echo "$misc_dir: \$i" >>\$log_file
    fi
done

cd /
tar \$tar_options \$device \$directories  2>&1 >>\$log_file
mt -f \$device \$exit_cmd 2>&1 >>\$log_file

echo "\n\n\t\t*** Backup complete ***\n" >>\$log_file

\$mail -s "\$machine BACKUP" \$admin <\$log_file
rm \$log_file
EOF

chmod 744 $backup_script
}

create_restore_cfg() {
#read_restore_settings

	cat > $restore_cfg <<- EOF
WWW_drive $WWW_drive
mail_root $mail_root
admin_root $admin_root
http_roots $http_roots
ftp_dir $ftp_dir
home_dir /export/home
savecfg_dir $savecfg_dir
misc_dir $WWW_misc_dir
EOF
}

backup()
{
	check_drive
	check_dirs
	check_days
	((time=WWW_time+WWW_ampm*12))

	if [[ $FORM_STATUS == "error" ]]; then
		exec index.cgi
	fi


	netra_html_success
	netra_html_head $backup_title

	if [[ -n $WWW_enabled ]]; then
		tmp=$enable
	else
		tmp=$disable
	fi
	print "<p><table border=0>"
	print "<td>$backup_label:<td>$tmp<tr>"
	show_drive

	if [[ -n $WWW_eject ]]; then
		tmp=$yes
		extra="rewoffl"
	else
		tmp=$no
		extra="rew"
	fi

	print "<td>$eject_label:<td>$tmp<tr>"
	show_dirs
	print "<td>$days_label:<td>$daylist<tr>"
	print "<td>$time_label:<td>"
	show_time
	print "</table>"
	cmd="0 $time * * $days $backup_script : backup-admin"

	netra_html_tail -u $MODCGI/index.cgi

	netra_cf_write $backup_cfg	\
		WWW_enabled		\
		WWW_drive		\
		WWW_mail		\
		WWW_html		\
		WWW_aftp		\
		WWW_home		\
		WWW_conf		\
		WWW_misc		\
		WWW_sunday		\
		WWW_monday		\
		WWW_tuesday		\
		WWW_wednesday		\
		WWW_thursday		\
		WWW_friday		\
		WWW_saturday		\
		WWW_eject		\
		time			\
		cmd

	config
	create_script
	create_restore_cfg
}

backup_now()
{
	tmp=/tmp/.backup.$$
	head=$immediate_backup_title
	check_drive
	check_dirs

	if [[ -n $FORM_STATUS ]]; then
		exec index.cgi
	fi

	if ! check_drive_status $WWW_drive; then
		netra_html_info	$(printf "$drive_not_ready_format" $WWW_drive)
		exec index.cgi
	fi

	for i in $restore_cfg $dirs
	do
        	directories="$directories .$i"
	done

	create_restore_cfg

	cd /
	if tar cvf /dev/rmt/$WWW_drive $directories > $tmp; then
		numfiles=$(wc -l $tmp | nawk '{print $1}')
		netra_html_success
		netra_html_head "$head"
		print "<table border=0>"
		show_drive
		show_dirs

		if [[ -n $WWW_eject ]]; then
			tmp=$yes
			mt -f /dev/rmt/$WWW_drive rewoffl
		else
			tmp=$no
			mt -f /dev/rmt/$WWW_drive rew
		fi
		print "<td>$eject_label:<td>$tmp<tr>"
		print "<td>$backup_files_count:<td>$numfiles<tr>"
		print "</table>"
	else
		netra_html_info $backup_problem_info
		netra_html_head "$head"
		print "<p>$unknown_backup_error"
	fi

	netra_html_tail -u $MODCGI/index.cgi
}

append() {
	eval var=\$$1
	if [[ -z $var ]]; then
		eval $1=$2
	else
		eval $1="\$$1,$2"
	fi
}

# main

netra_read_locale backup.msgs title.msgs
globals
eval $(get_locale_info)

case $WWW_op in
	backup)
		backup;;
	now)
		backup_now;;
	restore)
		restore;;
	*)
		;;
esac
